#include <avr/io.h>
#include <avr/interrupt.h>
#include <stdio.h>
#include "uart.h"
#include <util/delay.h>


volatile long counter = 0;
volatile long temp = 0;


/* Pripojenie periferii k vyvojovej doske Arduino: */

#define BAUD 9600


FILE mystdout = FDEV_SETUP_STREAM(uart_putc, NULL, _FDEV_SETUP_WRITE);

// External Interrupt 0 (INT0) Handler (PD2)
ISR(INT0_vect) {
	if (!(PIND & (1 << PIND3))) {
		counter++;
		} else {
		counter--;
	}
}

// External Interrupt 1 (INT1) Handler (PD3)
ISR(INT1_vect) {
	if (!(PIND & (1 << PIND2))) {
		counter--;
		} else {
		counter++;
	}
}



int main(void) {
	
	uart_init();                  // Inicializacia seriovej linky
	stdout = &mystdout;           // Odteraz funguje printf();
	
	// Set PD2 and PD3 as inputs with pull-up
	DDRD &= ~((1 << DDD2) | (1 << DDD3));      // Inputs
	PORTD |= (1 << PORTD2) | (1 << PORTD3);    // Enable pull-up resistors

	uart_init();

	// Enable external interrupts on INT0 and INT1 on rising edge
	EICRA |= (1 << ISC01) | (1 << ISC00);  // INT0: Rising edge
	EICRA |= (1 << ISC11) | (1 << ISC10);  // INT1: Rising edge

	EIMSK |= (1 << INT0) | (1 << INT1);    // Enable INT0 and INT1

	sei(); // Enable global interrupts

	while (1) {
		if (temp != counter) {
			temp = counter;
			printf("natocenie: %ld   \r",counter);
		}
	}

	return 0;
}